@@ -12,7 +12,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -30,19 +30,20 @@
 # *
 # **************************************************************************
 
-# we declare global constants to multiple usage
 import os
 
+
 # crYOLO ###############################################################################################################
 
 def getCryoloEnvName(version):
     return "cryolo-%s" % version
 
-
 V1_5_4 = "1.5.4"
 V1_6_1 = "1.6.1"
-VERSIONS = [V1_5_4, V1_6_1]
-CRYOLO_DEFAULT_VER_NUM = V1_6_1
+V1_7_2 = "1.7.2"
+
+VERSIONS = [V1_5_4, V1_6_1, V1_7_2]
+CRYOLO_DEFAULT_VER_NUM = V1_7_2
 
 DEFAULT_ENV_NAME = getCryoloEnvName(CRYOLO_DEFAULT_VER_NUM)
 DEFAULT_ACTIVATION_CMD = 'conda activate ' + DEFAULT_ENV_NAME
@@ -56,6 +57,7 @@ def _modelFn(modelKey):
 
 
 CRYOLO_GENMOD_VAR = 'CRYOLO_GENERIC_MODEL'
+CRYOLO_GENMOD_NN_VAR = 'CRYOLO_GENERIC_DENOISED_MODEL'
 CRYOLO_GENMOD = 'cryolo_model'
 
 CRYOLO_GENMOD_201909 = '201909'
@@ -64,23 +66,33 @@ CRYOLO_GENMOD_201909_FN = _modelFn(CRYOLO_GENMOD_201909)
 CRYOLO_GENMOD_201910 = '201910'
 CRYOLO_GENMOD_201910_FN = _modelFn(CRYOLO_GENMOD_201910)
 
-CRYOLO_GENMOD_202002_N63 = '202002_N63'
-CRYOLO_GENMOD_202002_N63_FN = _modelFn(CRYOLO_GENMOD_202002_N63)
+CRYOLO_GENMOD_202002 = '202002_N63'
+CRYOLO_GENMOD_202002_FN = _modelFn(CRYOLO_GENMOD_202002)
+
+CRYOLO_GENMOD_202005 = '202005_N63_c17'
+CRYOLO_GENMOD_202005_FN = _modelFn(CRYOLO_GENMOD_202005)
+
+CRYOLO_GENMOD_NN_202005 = '202005_nn_N63_c17'
+CRYOLO_GENMOD_NN_202005_FN = _modelFn(CRYOLO_GENMOD_NN_202005)
 
 # Default model (latest usually)
-CRYOLO_GENMOD_DEFAULT = os.path.join(CRYOLO_GENMOD + "-" + CRYOLO_GENMOD_202002_N63, CRYOLO_GENMOD_202002_N63_FN)
+CRYOLO_GENMOD_DEFAULT = os.path.join(CRYOLO_GENMOD + "-" + CRYOLO_GENMOD_202005,
+                                     CRYOLO_GENMOD_202005_FN)
+CRYOLO_GENMOD_NN_DEFAULT = os.path.join(CRYOLO_GENMOD + "-" + CRYOLO_GENMOD_NN_202005,
+                                        CRYOLO_GENMOD_NN_202005_FN)
 
 # crYOLO supported input formats for micrographs
 CRYOLO_SUPPORTED_FORMATS = [".mrc", ".tif", ".tiff", ".jpg"]
 
 # Input options for the training model
 INPUT_MODEL_GENERAL = 0
-INPUT_MODEL_GENERAL_NS = 2
-INPUT_MODEL_OTHER = 1
+INPUT_MODEL_GENERAL_DENOISED = 1
+INPUT_MODEL_OTHER = 2
+INPUT_MODEL_GENERAL_NS = 3
+
 
 # crYOLO - NEGATIVE STAIN ##############################################################################################
 
-
 def _negStainModelFn(modelKey):
     return 'gmodel_phosnet_negstain_{}.h5'.format(modelKey)
 
@@ -92,15 +104,15 @@ CRYOLO_NS_GENMOD_20190226_FN = _negStainModelFn(CRYOLO_NS_GENMOD_20190226)
 CRYOLO_NS_GENMOD_DEFAULT = os.path.join(CRYOLO_NS_GENMOD + "-" + CRYOLO_NS_GENMOD_20190226,
                                         CRYOLO_NS_GENMOD_20190226_FN)
 
-# JANNI ################################################################################################################
 
+# JANNI ################################################################################################################
 
 def _janniModelFn(modelKey):
     return 'gmodel_janni_{}.h5'.format(modelKey)
 
-
 JANNI_GENMOD_VAR = 'JANNI_GENERIC_MODEL'
 JANNI_GENMOD = "janni_model"  # Name
 JANNI_GENMOD_20190703 = "20190703"  # Version
 JANNI_GENMOD_20190703_FN = _janniModelFn(JANNI_GENMOD_20190703)  # File name with extension
-JANNI_GENMOD_DEFAULT = os.path.join("{}-{}".format(JANNI_GENMOD, JANNI_GENMOD_20190703), JANNI_GENMOD_20190703_FN)
+JANNI_GENMOD_DEFAULT = os.path.join("{}-{}".format(JANNI_GENMOD, JANNI_GENMOD_20190703),
+                                    JANNI_GENMOD_20190703_FN)
