@@ -7,7 +7,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -29,10 +29,9 @@ import os
 import csv
 import re
 
-import pyworkflow.object as pwobj
+import pyworkflow.utils as pwutils
 import pwem.objects as emobj
 from pwem.emlib.image import ImageHandler
-import pyworkflow.utils as pwutils
 from pwem.convert import Ccp4Header
 
 import sphire.constants as constants
@@ -185,7 +184,7 @@ def readMicrographCoords(mic, coordSet, coordsFile, boxSize, yFlipHeight=None, b
         coord.setObjId(None)
         coord.setPosition(x, y)
         coord.setMicrograph(mic)
-        coord._cryoloScore = pwobj.Float(score)
+        coord._cryoloScore = emobj.Float(score)
         # Add it to the set
         coordSet.append(coord)
 
